summaryrefslogtreecommitdiff
path: root/framework/source/inc
diff options
context:
space:
mode:
authorJulien Nabet <serval2412@yahoo.fr>2014-02-09 10:12:07 +0100
committerJulien Nabet <serval2412@yahoo.fr>2014-02-09 10:12:07 +0100
commit94bc29cb71d08ebe039d5ce5b6b2762ac24cbb8f (patch)
treeb24cede14403ab264d7f7684df3d603a15d2f010 /framework/source/inc
parent332fffe3b8cd51576c42762e5e9751464777f2ca (diff)
Typo: I/internaly -> I/internally
Change-Id: Ic9056baf58698743492ab57a882341c730ef2f7a
Diffstat (limited to 'framework/source/inc')
-rw-r--r--framework/source/inc/accelerators/acceleratorconfiguration.hxx2
-rw-r--r--framework/source/inc/accelerators/presethandler.hxx8
-rw-r--r--framework/source/inc/loadenv/loadenv.hxx4
3 files changed, 7 insertions, 7 deletions
diff --git a/framework/source/inc/accelerators/acceleratorconfiguration.hxx b/framework/source/inc/accelerators/acceleratorconfiguration.hxx
index 93388d304f34..4e4d6b9586af 100644
--- a/framework/source/inc/accelerators/acceleratorconfiguration.hxx
+++ b/framework/source/inc/accelerators/acceleratorconfiguration.hxx
@@ -263,7 +263,7 @@ class XMLBasedAcceleratorConfiguration : protected ThreadHelpBase,
/** @short returns a reference to one of our internal cache members.
@descr We implement the copy-on-write pattern. Doing so
- we know two caches internaly. The second one is used
+ we know two caches internally. The second one is used
only, if the container was changed.
This method here returns access to one of these
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index dadef232243d..f6c1bd7ac823 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -201,7 +201,7 @@ public:
/** @short initialize a new instance of this load environment.
@param xContext
- reference to an uno service manager, which can be used internaly
+ reference to an uno service manager, which can be used internally
to create on needed services on demand.
@throw Currently there is no reason to throw such exception!
@@ -429,7 +429,7 @@ private:
@return [string]
the type selected by the user.
- @attention Internaly we update the member m_lMediaDescriptor!
+ @attention Internally we update the member m_lMediaDescriptor!
*/
OUString impl_askUserForTypeAndFilterIfAllowed()
throw(LoadEnvException, css::uno::RuntimeException);
diff --git a/framework/source/inc/accelerators/presethandler.hxx b/framework/source/inc/accelerators/presethandler.hxx
index ef8c28af6dcb..45896436572e 100644
--- a/framework/source/inc/accelerators/presethandler.hxx
+++ b/framework/source/inc/accelerators/presethandler.hxx
@@ -226,7 +226,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
cant have any special parameters!
@param xContext
- points to an uno service manager, which is used internaly
+ points to an uno service manager, which is used internally
to create own needed uno resources.
*/
PresetHandler(const css::uno::Reference< css::uno::XComponentContext >& xContext);
@@ -244,7 +244,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
void forgetCachedStorages();
//---------------------------------------
/** @short return access to the internaly used and cached root storage.
@descr These root storages are the base of all further opened
presets and targets. They are provided here only, to support
@@ -252,7 +252,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
getOrCreate...() - What does it mean?
Such root storage will be created one times only and
- cached then internaly till the last instance of such PresetHandler
+ cached then internally till the last instance of such PresetHandler
dies.
@return com::sun::star::embed::XStorage
@@ -312,7 +312,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
Localzation will be represented as directory structure
of provided presets. Means: you call us with a preset name "default";
- and we use e.g. "/en-US/default.xml" internaly.
+ and we use e.g. "/en-US/default.xml" internally.
If no localization exists for this preset set, this class
will work in default mode - means "no locale" - automaticly.
@@ -244,7 +244,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
void forgetCachedStorages();
//---------------------------------------
- /** @short return access to the internaly used and cached root storage.
+ /** @short return access to the internally used and cached root storage.
presets and targets. They are provided here only, to support